@@ -44,6 +44,8 @@ static void	cb_toggle_tree (GtkAction *action, gpointer data);
 
 static const GtkActionEntry menu_entries[] =
 {
+	// xgettext: noun, top level menu.
+	// "File" did not make sense for system-monitor
 	{ "Monitor", NULL, N_("_Monitor") },
 	{ "Edit", NULL, N_("_Edit") },
 	{ "View", NULL, N_("_View") },
@@ -69,12 +71,6 @@ static const GtkActionEntry menu_entries[] =
 	{ "Preferences", GTK_STOCK_PREFERENCES, N_("Prefere_nces"), NULL,
 	  N_("Configure the application"), G_CALLBACK (cb_edit_preferences) },
 
-#if 0
-	{ "HideProcess", NULL, N_("_Hide Process"), "<control>H",
-	  N_("Hide process from list"), G_CALLBACK (cb_hide_process) },
-	{ "HiddenProcesses", NULL, N_("_Hidden Processes"), "<control>P",
-	  N_("Open the list of currently hidden processes"), G_CALLBACK (cb_show_hidden_processes) },
-#endif
 	{ "MemoryMaps", NULL, N_("_Memory Maps"), "<control>M",
 	  N_("Open the memory maps associated with a process"), G_CALLBACK (cb_show_memory_maps) },
 	{ "OpenFiles", NULL, N_("Open _Files"), "<control>F",
@@ -129,11 +125,6 @@ static const char ui_info[] =
 "      <separator />"
 "      <menuitem name=\"ViewDependenciesMenu\" action=\"ShowDependencies\" />"
 "      <separator />"
-#if 0
-"      <menuitem name=\"ViewHideProcessMenu\" action=\"HideProcess\" />"
-"      <menuitem name=\"ViewHiddenProcessesMenu\" action=\"HiddenProcesses\" />"
-"      <separator />"
-#endif
 "      <menuitem name=\"ViewMemoryMapsMenu\" action=\"MemoryMaps\" />"
 "      <menuitem name=\"ViewOpenFilesMenu\" action=\"OpenFiles\" />"
 "    </menu>"
@@ -151,10 +142,6 @@ static const char ui_info[] =
 "    <separator />"
 "    <menuitem action=\"ChangePriority\" />"
 "    <separator />"
-#if 0
-"    <menuitem action=\"HideProcess\" />"
-"    <separator />"
-#endif
 "    <menuitem action=\"MemoryMaps\" />"
 "    <menuitem action=\"OpenFiles\" />"
 "  </popup>";
@@ -180,7 +167,6 @@ create_proc_view (ProcData *procdata)
 	g_free (string);
 	gtk_box_pack_start (GTK_BOX (hbox1), procdata->loadavg, FALSE, FALSE, 0);
 
-	gtk_widget_show_all (hbox1);
 
 	scrolled = proctable_new (procdata);
 	if (!scrolled)
@@ -190,7 +176,6 @@ create_proc_view (ProcData *procdata)
 
 	gtk_box_pack_start (GTK_BOX (vbox1), scrolled, TRUE, TRUE, 0);
 	
-	gtk_widget_show_all (scrolled);
 	
 	hbox2 = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox2, FALSE, FALSE, 0);
@@ -200,7 +185,6 @@ create_proc_view (ProcData *procdata)
 	g_signal_connect (G_OBJECT (procdata->endprocessbutton), "clicked",
 			  G_CALLBACK (cb_end_process_button_pressed), procdata);
 	
-	gtk_widget_show_all (hbox2);
 	
 	/* create popup_menu */
  	procdata->popup_menu = gtk_ui_manager_get_widget (procdata->uimanager, "/PopupMenu");
@@ -227,17 +211,10 @@ make_title_label (const char *text)
 
 /* Make sure the cpu labels don't jump around. From the clock applet */
 static void
-cpu_size_request (GtkWidget *box, GtkRequisition *req, ProcData *procdata)
+size_request(GtkWidget* box, GtkRequisition* req, void* data)
 {
-	req->width = procdata->cpu_label_fixed_width = \
-		MAX(req->width, procdata->cpu_label_fixed_width);
-}
-
-static void
-net_size_request (GtkWidget *label, GtkRequisition *req, ProcData *procdata)
-{
-	req->width = procdata->net_label_fixed_width = \
-		MAX(req->width, procdata->net_label_fixed_width);
+  gint* size = static_cast<gint*>(data);
+  req->width = *size = std::max(req->width, *size);
 }
 
 
@@ -246,6 +223,9 @@ net_size_request (GtkWidget *label, GtkRequisition *req, ProcData *procdata)
 static GtkWidget *
 create_sys_view (ProcData *procdata)
 {
+  static gint net_size;
+  static gint cpu_size;
+
 	GtkWidget *vbox, *hbox;
 	GtkWidget *cpu_box, *mem_box, *net_box;
 	GtkWidget *cpu_hbox, *mem_hbox, *net_hbox;
@@ -268,7 +248,6 @@ create_sys_view (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (vbox), cpu_box, TRUE, TRUE, 0);
 
 	label = make_title_label (_("CPU History"));
-	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (cpu_box), label, FALSE, FALSE, 0);
 	
 	cpu_hbox = gtk_hbox_new (FALSE, 0);
@@ -289,18 +268,26 @@ create_sys_view (ProcData *procdata)
 
 	sizegroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
-	hbox = gtk_hbox_new (FALSE, 12);
-	gtk_box_pack_start (GTK_BOX (cpu_graph_box), hbox, FALSE, FALSE, 0);
+	GtkWidget* cpu_table = gtk_table_new(std::min(procdata->config.num_cpus / 4, 1),
+					     std::min(procdata->config.num_cpus, 4),
+					     TRUE);
+	gtk_table_set_row_spacings(GTK_TABLE(cpu_table), 6);
+	gtk_table_set_col_spacings(GTK_TABLE(cpu_table), 12);
+	gtk_box_pack_start(GTK_BOX(cpu_graph_box), cpu_table, FALSE, FALSE, 0);
 
 	for (i=0;i<procdata->config.num_cpus; i++) {
 		GtkWidget *temp_hbox;
 		gchar *text;
 		
 		temp_hbox = gtk_hbox_new (FALSE, 6);
-		gtk_box_pack_start (GTK_BOX (hbox), temp_hbox, FALSE, FALSE, 0);
+		gtk_table_attach(GTK_TABLE(cpu_table), temp_hbox,
+				 i % 4, i % 4 + 1,
+				 i / 4, i / 4 + 1,
+				 GTK_FILL, GTK_FILL,
+				 0, 0);
 		gtk_size_group_add_widget (sizegroup, temp_hbox);
 		g_signal_connect (G_OBJECT (temp_hbox), "size_request",
-					 G_CALLBACK (cpu_size_request), procdata);
+					 G_CALLBACK(size_request), &cpu_size);
 
 		color_picker = gtk_color_button_new_with_color (
 			&load_graph_get_colors(cpu_graph)[2+i]);
@@ -334,7 +321,6 @@ create_sys_view (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (vbox), mem_box, TRUE, TRUE, 0);
 
 	label = make_title_label (_("Memory and Swap History"));
-	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (mem_box), label, FALSE, FALSE, 0);
 	
 	mem_hbox = gtk_hbox_new (FALSE, 0);
@@ -383,7 +369,7 @@ create_sys_view (ProcData *procdata)
 			  GTK_FILL,
 			  0,
 			  0);
-	
+	// xgettext: user memory: 123 MiB of 512MiB
 	label = gtk_label_new (_("of"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 3, 4, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
@@ -443,7 +429,7 @@ create_sys_view (ProcData *procdata)
 			  GTK_FILL,
 			  0,
 			  0);
-			  
+	// xgettext: swap: 10MiB of 1GiB
 	label = gtk_label_new (_("of"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 3, 4, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
@@ -485,7 +471,6 @@ create_sys_view (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (vbox), net_box, TRUE, TRUE, 0);
 
 	label = make_title_label (_("Network History"));
-	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (net_box), label, FALSE, FALSE, 0);
 
 	net_hbox = gtk_hbox_new (FALSE, 0);
@@ -522,7 +507,7 @@ create_sys_view (ProcData *procdata)
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	g_signal_connect (G_OBJECT (hbox), "size_request",
-			  G_CALLBACK (net_size_request), procdata);
+			  G_CALLBACK(size_request), &net_size);
 
 
 	gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(net_graph)->net_in),
@@ -566,7 +551,7 @@ create_sys_view (ProcData *procdata)
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	g_signal_connect (G_OBJECT (hbox), "size_request",
-			  G_CALLBACK (net_size_request), procdata);
+			  G_CALLBACK(size_request), &net_size);
 
 	gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(net_graph)->net_out),
 				0.0,
@@ -599,9 +584,6 @@ create_sys_view (ProcData *procdata)
 
 	procdata->net_graph = net_graph;
 
-
-	gtk_widget_show_all (vbox);
-
 	return vbox;
 }
 
@@ -654,9 +636,9 @@ disconnect_proxy_cb (GtkUIManager *manager,
 {
 	if (GTK_IS_MENU_ITEM (proxy)) {
 		g_signal_handlers_disconnect_by_func
-			(proxy, reinterpret_cast<void*>(G_CALLBACK(menu_item_select_cb)), procdata);
+			(proxy, (void*)(G_CALLBACK(menu_item_select_cb)), procdata);
 		g_signal_handlers_disconnect_by_func
-			(proxy, reinterpret_cast<void*>(G_CALLBACK(menu_item_deselect_cb)), procdata);
+			(proxy, (void*)(G_CALLBACK(menu_item_deselect_cb)), procdata);
 	}
 }
 
@@ -737,28 +719,20 @@ create_main_window (ProcData *procdata)
 	                    TRUE, 
 	                    TRUE, 
 	                    0);
-	gtk_widget_show (notebook);
 
 	sysinfo_box = procman_create_sysinfo_view();
-	gtk_widget_show_all(sysinfo_box);
 	sysinfo_label = gtk_label_new(_("System"));
-	gtk_widget_show(sysinfo_label);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), sysinfo_box, sysinfo_label);
 
 	vbox1 = create_proc_view (procdata);
-	gtk_widget_show (vbox1);
 	tab_label1 = gtk_label_new (_("Processes"));
-	gtk_widget_show (tab_label1);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox1, tab_label1);
 	
 	sys_box = create_sys_view (procdata);
-	gtk_widget_show (sys_box);
 	tab_label2 = gtk_label_new (_("Resources"));
-	gtk_widget_show (tab_label2);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sys_box, tab_label2);
 
 	devices_box = create_disk_view (procdata);
-	gtk_widget_show(devices_box);
 	tab_label3 = gtk_label_new (_("File Systems"));
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), devices_box, tab_label3);
 
@@ -767,7 +741,7 @@ create_main_window (ProcData *procdata)
 	g_signal_connect (G_OBJECT (notebook), "change-current-page",
 			  G_CALLBACK (cb_change_current_page), procdata);
 
-
+	gtk_widget_show_all(notebook); // need to make page switch work
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), procdata->config.current_tab);
 	cb_change_current_page (GTK_NOTEBOOK (notebook), procdata->config.current_tab, procdata);
 	g_signal_connect (G_OBJECT (app), "delete_event",
@@ -793,8 +767,8 @@ create_main_window (ProcData *procdata)
 void
 do_popup_menu (ProcData *procdata, GdkEventButton *event)
 {
-	gint button;
-	gint event_time;
+	guint button;
+	guint32 event_time;
 
 	if (event) {
 		button = event->button;
@@ -817,19 +791,13 @@ update_sensitivity(ProcData *data)
 						  "EndProcess",
 						  "KillProcess",
 						  "ChangePriority",
-#if 0
-						  "HideProcess",
-#endif
 						  "MemoryMaps",
 						  "OpenFiles" };
 
 	const char * const processes_actions[] = { "ShowActiveProcesses",
 						   "ShowAllProcesses",
 						   "ShowMyProcesses",
-						   "ShowDependencies",
-#if 0
-						   "HiddenProcesses"
-#endif
+						   "ShowDependencies"
 	};
 
 	size_t i;
